@@ -10,8 +10,7 @@ from skepticoin.consensus import (
 )
 
 from .utils import (
-    initialize_peers_file,
-    create_chain_dir,
+    check_chain_dir,
     read_chain_from_disk,
     open_or_init_wallet,
     start_networking_peer_in_background,
@@ -21,7 +20,7 @@ from .utils import (
 )
 
 
-def main():
+def main() -> None:
     parser = DefaultArgumentParser()
     parser.add_argument("amount", help="The amount of to send", type=int)
     parser.add_argument("denomination", help="'skepticoin' or 'sashimi'", choices=['skepticoin', 'sashimi'])
@@ -35,10 +34,9 @@ def main():
         print("Invalid address")
         return
 
-    create_chain_dir()
+    check_chain_dir()
     coinstate = read_chain_from_disk()
     wallet = open_or_init_wallet()
-    initialize_peers_file()
     thread = start_networking_peer_in_background(args, coinstate)
 
     try:
@@ -61,6 +59,7 @@ def main():
         )
 
         validate_non_coinbase_transaction_by_itself(transaction)
+        assert coinstate.current_chain_hash
         validate_non_coinbase_transaction_in_coinstate(transaction, coinstate.current_chain_hash, coinstate)
 
         print("Broadcasting transaction on the network", transaction)
@@ -73,6 +72,7 @@ def main():
 
             # it's late and I'm too lazy for the efficient & correct implementation.
             coinstate = thread.local_peer.chain_manager.coinstate
+
             max_height = coinstate.head().height
 
             for i in range(10):
